==> ikapi-2.4.4.tgz: package/src/Database/DDB/_IKDBQueryTransactionalRead.js <==
import IKDBQuery from './IKDBQuery';
//
export default class IKDBQueryPut extends IKDBQuery {
  constructor() {
    super();
    this.putItems = {};
  }
  /*public methods*/
  //return if the value was appended or not
  appendValue(source, key, isObject) {
    //check for optional value
    if (isObject == undefined) isObject = false;
    //check if value is valid
    if (source[key] != undefined &&
       ((Object.keys(source[key]).length > 0) ||
        (!isNaN(source[key]) && source[key].length != 0) ||
        (source[key].length > 0))) {
      //Check for object conversion
      let val;
      if (isObject) val = {"M": AWS.DynamoDB.Converter.marshall(source[key])};
      else val = AWS.DynamoDB.Converter.input(source[key]);
      //valid
      if (val != undefined) { this.putItems[key]= val; }
      console.debug("Apppending key:", key, " val:", val);
      return true;
    } return false;
  }
  setItems(items) { this.putItems = items; }
  async run(dbManager) {
    const localConsole = (dbManager.transaction ? dbManager.transaction.logger : console);
    const query = this.__rawQuery(dbManager.tableName);
    localConsole.log('Putting item: ', query);
    const resp = await dbManager.connection.putItem(query).promise();
    localConsole.log('Raw result: ', resp);
    const unmarshalled = resp.Items.map(AWS.DynamoDB.Converter.unmarshall);
    localConsole.log('Parsed result: ', unmarshalled);
    return unmarshalled;
  }

  /*private methods*/
  __rawQuery(dbTableName) {
    return { ...this._rawQuery(dbTableName),
             Item: this.putItems, ReturnValues: "ALL_NEW" /*request new values added*/ };
  }
}

==> ikapi-2.6.6.tgz: package/src/Database/DDB/_IKDBQueryTransactionalRead.js <==
import IKDBQuery from './IKDBQuery';
//
export default class IKDBQueryPut extends IKDBQuery {
  constructor() {
    super();
    this.putItems = {};
  }
  /*public methods*/
  //return if the value was appended or not
  appendValue(source, key, isObject) {
    //check for optional value
    if (isObject == undefined) isObject = false;
    //check if value is valid
    if (source[key] != undefined &&
       ((Object.keys(source[key]).length > 0) ||
        (!isNaN(source[key]) && source[key].length != 0) ||
        (source[key].length > 0))) {
      //Check for object conversion
      let val;
      if (isObject) val = {"M": AWS.DynamoDB.Converter.marshall(source[key])};
      else val = AWS.DynamoDB.Converter.input(source[key]);
      //valid
      if (val != undefined) { this.putItems[key]= val; }
      // console.debug("Apppending key:", key, " val:", val);
      return true;
    } return false;
  }
  setItems(items) { this.putItems = items; }
  async run(dbManager) {
    const localConsole = (dbManager.transaction ? dbManager.transaction.logger : console);
    const query = this.__rawQuery(dbManager.tableName);
    localConsole.log('Putting item: ', query);
    const resp = await dbManager.connection.putItem(query).promise();
    // localConsole.log('Raw result: ', resp);
    const unmarshalled = resp.Items.map(AWS.DynamoDB.Converter.unmarshall);
    localConsole.log('Parsed result: ', unmarshalled);
    return unmarshalled;
  }

  /*private methods*/
  __rawQuery(dbTableName) {
    return { ...this._rawQuery(dbTableName),
             Item: this.putItems, ReturnValues: "ALL_NEW" /*request new values added*/ };
  }
}
